@@ -104,9 +104,3 @@ class WebhookRequest(BaseModel):
     responseId: str
     queryResult: QueryResult
     originalDetectIntentRequest: OriginalDetectIntentRequest | None
-
-
-request = WebhookRequest.parse_file("tests\\request-01.json")
-
-print(request)
-
