@@ -32,7 +32,3 @@ class WebhookResponse(BaseModel):
     outputContext: List[Context] | None
     followupEventInput: EventInput | None
     sessionEntityTypes: List[SessionEntityType] | None
-
-a = WebhookResponse.construct()
-a = a.json(exclude_none=True)
-print(a)
